Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(404)

Unified Diff: extensions/renderer/messaging_bindings.h

Issue 709933002: Add frameId to MessageSender (extension messaging API) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: test: sender.tab.status = 'complete' Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « extensions/renderer/extension_helper.cc ('k') | extensions/renderer/messaging_bindings.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: extensions/renderer/messaging_bindings.h
diff --git a/extensions/renderer/messaging_bindings.h b/extensions/renderer/messaging_bindings.h
index 422dcae7ae9356f208f1cedea3471a3d7c142dda..a7a1c6fef80704a7449403763e32ddfd9f409d7f 100644
--- a/extensions/renderer/messaging_bindings.h
+++ b/extensions/renderer/messaging_bindings.h
@@ -10,13 +10,14 @@
#include "extensions/renderer/script_context_set.h"
struct ExtensionMsg_ExternalConnectionInfo;
+struct ExtensionMsg_TabConnectionInfo;
namespace base {
class DictionaryValue;
}
namespace content {
-class RenderView;
+class RenderFrame;
}
namespace v8 {
@@ -41,30 +42,30 @@ class MessagingBindings {
ScriptContext* context);
// Dispatches the onConnect content script messaging event to some contexts
// in |context_set|. If |restrict_to_render_view| is specified, only contexts
// in that render view will receive the message.
static void DispatchOnConnect(const ScriptContextSet& context_set,
int target_port_id,
const std::string& channel_name,
- const base::DictionaryValue& source_tab,
+ const ExtensionMsg_TabConnectionInfo& source,
const ExtensionMsg_ExternalConnectionInfo& info,
const std::string& tls_channel_id,
- content::RenderView* restrict_to_render_view);
+ content::RenderFrame* restrict_to_render_frame);
// Delivers a message sent using content script messaging to some of the
// contexts in |bindings_context_set|. If |restrict_to_render_view| is
// specified, only contexts in that render view will receive the message.
static void DeliverMessage(const ScriptContextSet& context_set,
int target_port_id,
const Message& message,
- content::RenderView* restrict_to_render_view);
+ content::RenderFrame* restrict_to_render_frame);
// Dispatches the onDisconnect event in response to the channel being closed.
static void DispatchOnDisconnect(
const ScriptContextSet& context_set,
int port_id,
const std::string& error_message,
- content::RenderView* restrict_to_render_view);
+ content::RenderFrame* restrict_to_render_frame);
};
} // namespace extensions
« no previous file with comments | « extensions/renderer/extension_helper.cc ('k') | extensions/renderer/messaging_bindings.cc » ('j') | no next file with comments »
@@ -41,30 +42,30 @@ class MessagingBindings {
ScriptContext* context);
// Dispatches the onConnect content script messaging event to some contexts
- // in |context_set|. If |restrict_to_render_view| is specified, only contexts
- // in that render view will receive the message.
+ // in |context_set|. If |restrict_to_render_frame| is specified, only contexts
+ // in that render frame will receive the message.
static void DispatchOnConnect(const ScriptContextSet& context_set,
int target_port_id,
@@ -41,30 +42,30 @@ class MessagingBindings {
// Delivers a message sent using content script messaging to some of the
- // contexts in |bindings_context_set|. If |restrict_to_render_view| is
+ // contexts in |bindings_context_set|. If |restrict_to_render_frame| is
// specified, only contexts in that render view will receive the message.
static void DeliverMessage(const ScriptContextSet& context_set,

Powered by Google App Engine
This is Rietveld 408576698